<?php
/**
* Textifier
*
* calls the specific textifier function
*
*/

class Yatmo_Textifier {
    /**
    * Summary
    * @var string $summary
    */
    public $summary = '';
	
	function quota_exceeded(){
		?>
		<div class="notice notice-error is-dismissible">
			<p><?php _e('Yatmo Text Plugin: dear user, it seems your daily quota has been exceeded: you can wait for 24h or subscribe to our services (or take a bigger subscription if you already have one) thanks to the following link:', 'yatmo-text'); ?></p>
			<a href="https://yatmo.com/en/account/register" target="_blank">https://yatmo.com/en/account/register</a>
		</div>
		<?php
	}
	
    /**
    * new Textifier from latitude, longitude
    *
    * handles url encoding and caching
    *
    * @param float $latitude the requested latitude to look up
    * @param float $longitude the requested longitude to look up
    * @param string $licenseKey the license key to use
    * @return NOTHING
    */
    public function __construct ($latitude, $longitude, $licenseKey) {
        $settings = yatmo_text_Plugin_Settings::init();
	
        $textifier = $settings->get('textifier');

        $cached_summary = 'yatmo_' . $textifier . '_' . $latitude . '_' . $longitude;

        /* retrieve cached summary */
        $found_cache = get_option( $cached_summary );

        if ( $found_cache ) {
            $this->summary = (string) $found_cache;
        } else {
            try {
                $this->summary = (string) $this->find_summary( $latitude, $longitude, $licenseKey );

                /* add summary */
                add_option($cached_summary, $this->summary);

                /* add option key to locations for clean up purposes */
                $summaries = get_option('yatmo_geocoded_summaries', array());
                array_push($summaries, $cached_summary);
                update_option('yatmo_geocoded_summaries', $summaries);
            } catch (Exception $e) {		
				add_action('admin_notices', array($this, 'quota_exceeded'));
		
                $this->summary = '';
            }
        }
    }

    /**
    * Removes summary caches
    */
    public static function remove_caches () {
        $summaries = get_option('yatmo_geocoded_summaries', array());
        foreach ($summaries as $summarytodelete) {
            delete_option($summarytodelete);
        }
        delete_option('yatmo_geocoded_summaries');
    }

    /**
    * Used by geocoders to make requests via curl or file_get_contents
    *
    * includes a try/catch
    *
    * @param string $url    the urlencoded request url
    * @return varies object from API or null (failed)
    */
    private function get_url( $url ) {
        $referer = get_site_url();

        if (in_array('curl', get_loaded_extensions())) {
            /* try curl */
            $ch = curl_init();

            curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
            curl_setopt($ch, CURLOPT_HEADER, 0);
                    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
                    curl_setopt($ch, CURLOPT_REFERER, $referer);
            curl_setopt($ch, CURLOPT_URL, $url);
            curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);

            $data = curl_exec($ch);
            curl_close($ch);

            return $data;
        } else if (ini_get('allow_url_fopen')) {
                    /* try file get contents */

                    $opts = array(
                        'http' => array(
                            'header' => array("Referer: $referer\r\n")
                        )
                    );
                    $context = stream_context_create($opts);

            return file_get_contents($url, false, $context);
        }

        $error_msg = 'Could not get url: ' . $url;
        throw new Exception( $error_msg );
    }

    /**
    * Yatmo summary generator (https://yatmo.com)
    *
    * @param string $address    the urlencoded address to look up
    * @return varies object from API or null (failed)
    */

    private function find_summary ( $latitude, $longitude, $licenseKey ) {
        $summary_url = 'https://planet.yatmo.com/Summary/text?latitude=' . $latitude . '&longitude=' . $longitude . '&licenseKey=' . urlencode($licenseKey);
        $summary_url .= $address;
        $json = $this->get_url($summary_url);

        return $json;
    }
}