<?php
/**
 * Map Shortcode
 *
 * Displays map with [yatmo-text ...atts] 
 * 
 * @author   Yatmo SRL
 * @category Shortcode
 */

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
} 

require_once yatmo_text__PLUGIN_DIR . 'shortcodes/class.shortcode.php';

/**
 * yatmo_text_Shortcode Class
 */
class yatmo_text_Shortcode extends Yatmo_TextPlugin_Shortcode
{
	/**
    * TLDs
    * @var array $tlds
    */
    private $tlds;
	
    /**
     * Instantiate class
     */
    public function __construct()
    {
        parent::__construct();

        $this->enqueue();
		
		$tlds = json_decode('{ ".aw":"AW",".af":"AF",".ao":"AO",".ai":"AI",".ax":"AX",".al":"AL",".ad":"AD",".ae":"AE",".ar":"AR",".am":"AM",".as":"AS",".aq":"AQ",".tf":"TF",".ag":"AG",".au":"AU",".at":"AT",".az":"AZ",".bi":"BI",".be":"BE",".bj":"BJ",".bf":"BF",".bd":"BD",".bg":"BG",".bh":"BH",".bs":"BS",".ba":"BA",".bl":"BL",".by":"BY",".bz":"BZ",".bm":"BM",".bo":"BO",".br":"BR",".bb":"BB",".bn":"BN",".bt":"BT",".bv":"BV",".bw":"BW",".cf":"CF",".ca":"CA",".cc":"CC",".ch":"CH",".cl":"CL",".cn":"CN",".ci":"CI",".cm":"CM",".cd":"CD",".cg":"CG",".ck":"CK",".co":"CO",".km":"KM",".cv":"CV",".cr":"CR",".cu":"CU",".cw":"CW",".cx":"CX",".ky":"KY",".cy":"CY",".cz":"CZ",".de":"DE",".dj":"DJ",".dm":"DM",".dk":"DK",".do":"DO",".dz":"DZ",".ec":"EC",".eg":"EG",".er":"ER",".eh":"EH",".es":"ES",".ee":"EE",".et":"ET",".fi":"FI",".fj":"FJ",".fk":"FK",".fr":"FR",".fo":"FO",".fm":"FM",".ga":"GA",".uk":"GB",".ge":"GE",".gg":"GG",".gh":"GH",".gi":"GI",".gn":"GN",".gp":"GP",".gm":"GM",".gw":"GW",".gq":"GQ",".gr":"GR",".gd":"GD",".gl":"GL",".gt":"GT",".gf":"GF",".gu":"GU",".gy":"GY",".hk":"HK",".hm":"HM",".hn":"HN",".hr":"HR",".ht":"HT",".hu":"HU",".id":"ID",".im":"IM",".in":"IN",".io":"IO",".ie":"IE",".ir":"IR",".iq":"IQ",".is":"IS",".il":"IL",".it":"IT",".jm":"JM",".je":"JE",".jo":"JO",".jp":"JP",".kz":"KZ",".ke":"KE",".kg":"KG",".kh":"KH",".ki":"KI",".kn":"KN",".kr":"KR",".kw":"KW",".la":"LA",".lb":"LB",".lr":"LR",".ly":"LY",".lc":"LC",".li":"LI",".lk":"LK",".ls":"LS",".lt":"LT",".lu":"LU",".lv":"LV",".mo":"MO",".fr":"MF",".ma":"MA",".mc":"MC",".md":"MD",".mg":"MG",".mv":"MV",".mx":"MX",".mh":"MH",".mk":"MK",".ml":"ML",".mt":"MT",".mm":"MM",".me":"ME",".mn":"MN",".mp":"MP",".mz":"MZ",".mr":"MR",".ms":"MS",".mq":"MQ",".mu":"MU",".mw":"MW",".my":"MY",".yt":"YT",".na":"NA",".nc":"NC",".ne":"NE",".nf":"NF",".ng":"NG",".ni":"NI",".nu":"NU",".nl":"NL",".no":"NO",".np":"NP",".nr":"NR",".nz":"NZ",".om":"OM",".pk":"PK",".pa":"PA",".pn":"PN",".pe":"PE",".ph":"PH",".pw":"PW",".pg":"PG",".pl":"PL",".pr":"PR",".kp":"KP",".pt":"PT",".py":"PY",".ps":"PS",".pf":"PF",".qa":"QA",".re":"RE",".ro":"RO",".ru":"RU",".rw":"RW",".sa":"SA",".sd":"SD",".sn":"SN",".sg":"SG",".gs":"GS",".sj":"SJ",".sb":"SB",".sl":"SL",".sv":"SV",".sm":"SM",".so":"SO",".pm":"PM",".rs":"RS",".ss":"SS",".st":"ST",".sr":"SR",".sk":"SK",".si":"SI",".se":"SE",".sz":"SZ",".sx":"SX",".sc":"SC",".sy":"SY",".tc":"TC",".td":"TD",".tg":"TG",".th":"TH",".tj":"TJ",".tk":"TK",".tm":"TM",".tl":"TL",".to":"TO",".tt":"TT",".tn":"TN",".tr":"TR",".tv":"TV",".tw":"TW",".tz":"TZ",".ug":"UG",".ua":"UA",".us":"UM",".uy":"UY",".us":"US",".uz":"UZ",".va":"VA",".vc":"VC",".ve":"VE",".vg":"VG",".vi":"VI",".vn":"VN",".vu":"VU",".wf":"WF",".ws":"WS",".ye":"YE",".za":"ZA",".zm":"ZM",".zw":"ZW" }');
    }

    /**
     * Enqueue Scripts and Styles for Yatmo 
     * 
     * @return null
     */
    protected function enqueue()
    {
        do_action('yatmo_text_enqueue');
    }

    /**
     * Merge shortcode options with default options
     *
     * @param array|string $atts    key value pairs from shortcode 
     * 
     * @return array new atts, which is actually an array
     */
    protected function getAtts($atts='')
    {
        $atts = (array) $atts;
        extract($atts, EXTR_SKIP);

        $settings = yatmo_text_Plugin_Settings::init();

        $atts['language'] = array_key_exists('language', $atts) ? $language : $settings->get('default_language');
        $atts['openingtitlenodetype'] = array_key_exists('openingtitlenodetype', $atts) ? $openingtitlenodetype : $settings->get('default_openingtitlenodetype');
        $atts['closingtitlenodetype'] = array_key_exists('closingtitlenodetype', $atts) ? $closingtitlenodetype : $settings->get('default_closingtitlenodetype');
        $atts['openingparagraphnodetype'] = array_key_exists('openingparagraphnodetype', $atts) ? $openingparagraphnodetype : $settings->get('default_openingparagraphnodetype');
        $atts['closingparagraphnodetype'] = array_key_exists('closingparagraphnodetype', $atts) ? $closingparagraphnodetype : $settings->get('default_closingparagraphnodetype');
        $atts['openingkeywordnodetype'] = array_key_exists('openingkeywordnodetype', $atts) ? $openingkeywordnodetype : $settings->get('default_openingkeywordnodetype');
        $atts['closingkeywordnodetype'] = array_key_exists('closingkeywordnodetype', $atts) ? $closingkeywordnodetype : $settings->get('default_closingkeywordnodetype');
        $atts['visibleparagraphs'] = array_key_exists('visibleparagraphs', $atts) ? $visibleparagraphs : $settings->get('default_visibleparagraphs');
        $atts['showstreetnameintitle'] = array_key_exists('showstreetnameintitle', $atts) ? $showstreetnameintitle : $settings->get('default_showstreetnameintitle');
        $atts['showplacenameintitle'] = array_key_exists('showplacenameintitle', $atts) ? $showplacenameintitle : $settings->get('default_showplacenameintitle');
        
        return $atts;
    }
	
    /**
     * Get script for shortcode
     * 
     * @param array  $atts    sometimes this is null
     * @param string $content anything within a shortcode
     * 
     * @return string HTML
     */
    protected function getHTML($atts='', $content=null)
    {
        extract($this->getAtts($atts));

        if (!empty($address)) {
            /* try geocoding */
            include_once yatmo_text__PLUGIN_DIR . 'class.geocoder.php';            
            $location = new Yatmo_Geocoder($address);
            $lat = $location->lat;
            $lng = $location->lng;
        }

        $settings = yatmo_text_Plugin_Settings::init();

        // map uses lat/lng
        $lat = isset($lat) ? $lat : $settings->get('default_lat');
        $lng = isset($lng) ? $lng : $settings->get('default_lng');
		
        $licenseKey = $settings->get('yatmo_key');
		
		$licenseKeyPresent = true;
		if (empty($licenseKey) || $licenseKey === null) {
            $licenseKey = parse_url(get_site_url(), PHP_URL_HOST);
			$licenseKeyPresent = false;
        }		
        
        // validate lat/lng
        $lat = $this->LM->filter_float($lat);
        $lng = $this->LM->filter_float($lng);
		
		include_once yatmo_text__PLUGIN_DIR . 'class.yatmo-textifier.php';
		$textifier = new Yatmo_Textifier($lat, $lng, $licenseKey);
		$summary = json_decode($textifier->summary, true);
		$html = '';
		
		$cpt = 1;
		foreach($summary['Paragraphs'] as $key=>$paragraph) {
			if (str_contains($visibleparagraphs, $paragraph['IconId'])){
				$typeoftitle = 'Title';
				
				if ($showstreetnameintitle == 1 && $cpt == 1 && !empty($paragraph['TitleBis'])){
					$typeoftitle = 'TitleBis';
				}
				
				if ($showplacenameintitle == 1 && $cpt == 2 && !empty($paragraph['TitleTer'])){
					$typeoftitle = 'TitleTer';
				}
				
				$paragraphtitle = $paragraph[$typeoftitle][$language];
			
				$html .= $openingtitlenodetype . $paragraphtitle . $closingtitlenodetype;
				
				foreach($paragraph['Sentences'] as $key=>$sentence) {
					$paragraphsentence = $sentence[$language];
					
					$paragraphsentence = str_replace('[STRONG]', $openingkeywordnodetype, $paragraphsentence);
					$paragraphsentence = str_replace('[/STRONG]', $closingkeywordnodetype, $paragraphsentence);				
					
					$html .= $openingparagraphnodetype . $paragraphsentence . $closingparagraphnodetype;
				}
				
				$cpt++;
			}
		}
		
		if ($licenseKeyPresent == false){
			$detectedTld = "." + end(explode(".", parse_url(get_site_url(), PHP_URL_HOST)));
			$country = '';
			
			if (array_key_exists($detectedTld, $tlds)) {
				$country .= '/' . strtolower(tlds[$detectedTld]);
			}
			
			$yatmoUrl = 'https://yatmo.com/world/' . strtolower($language) . $country;
			
			$html .= '<br><div style="text-align:right;"><a href="' . $yatmoUrl . '" target="_blank"><img src="' . plugin_dir_url( __FILE__ ) . 'includes/images/powered_yatmo.png" alt="Powered by Yatmo"></a></div>';
		}

        return '<div class="yatmo-text">' . $html . '</div>';
    }
}