<?php
/**
 * Settings View
 * 
 * PHP Version 5.5
 * 
 * @category Admin
 * @author   Yatmo SRL
 */

$title = $plugin_data['Name'];
$description = __('A plugin for creating a Yatmo JS map with a shortcode. Don\'t worry, our map is free if you don\'t use more than 500 map loads per day ;-)', 'yatmo-text');
$version = $plugin_data['Version'];
?>
<div class="wrap">

<h1><?php echo $title; ?> <small>version: <?php echo $version; ?></small></h1>

<?php
/** START FORM SUBMISSION */

// validate nonce!
define('NONCE_NAME', 'yatmo-text-nonce');
define('NONCE_ACTION', 'yatmo-text-action');

function verify_nonce () {
    $verified = (
        isset($_POST[NONCE_NAME]) &&
        check_admin_referer(NONCE_ACTION, NONCE_NAME)
    );

    if (!$verified) {
        // side-effects can be fun?
        ?>
        <div class="notice notice-error is-dismissible">
            <p><?php _e('Sorry, your nonce did not verify', 'yatmo-text'); ?></p>
        </div>
        <?php
    }

    return $verified;
}

if (isset($_POST['submit']) && verify_nonce()) {
    /* copy and overwrite $post for checkboxes */
    $form = $_POST;

    foreach ($settings->options as $name => $option) {
        if (!$option->type) continue;

        /* checkboxes don't get sent if not checked */
        if ($option->type === 'checkbox') {
            $form[$name] = isset($_POST[ $name ]) ? 1 : 0;
        }

        $value = trim( stripslashes( $form[$name]) );

        $settings->set($name, $value);
    }
?>
<div class="notice notice-success is-dismissible">
    <p><?php _e('Options Updated!', 'yatmo-text'); ?></p>
</div>
<?php
} elseif (isset($_POST['reset']) && verify_nonce()) {
    $settings->reset();
?>
<div class="notice notice-success is-dismissible">
    <p><?php _e('Options have been reset to default values!', 'yatmo-text'); ?></p>
</div>
<?php
} elseif (isset($_POST['clear-geocoder-cache']) && verify_nonce()) {
    include_once yatmo_text__PLUGIN_DIR . 'class.geocoder.php';
    Yatmo_Geocoder::remove_caches();
	
    include_once yatmo_text__PLUGIN_DIR . 'class.yatmo-textifier.php';
    Yatmo_Textifier::remove_caches();
?>
<div class="notice notice-success is-dismissible">
    <p><?php _e('Location caches have been cleared!', 'yatmo-text'); ?></p>
</div>
<?php
}
/** END FORM SUBMISSION */

?>

<p><?php echo $description; ?></p>
<h3><?php _e('Found an issue?', 'yatmo-text') ?></h3>
<p><?php _e('Post it to ', 'yatmo-text') ?><b><?php _e('WordPress Support', 'yatmo-text') ?></b>: <a href="https://wordpress.org/support/plugin/yatmo-text/" target="_blank">Yatmo Text (WordPress)</a></p>

<div class="wrap">
    <div class="wrap">
    <form method="post">
        <?php wp_nonce_field(NONCE_ACTION, NONCE_NAME); ?>
        <div class="container">
            <h2><?php _e('Settings', 'yatmo-text'); ?></h2>
            <hr>
        </div>
    <?php
    foreach ($settings->options as $name => $option) {
        if (!$option->type) continue;
    ?>
    <div class="container">
        <label>
            <span class="label"><?php echo $option->display_name; ?></span>
            <span class="input-group">
            <?php
            $option->widget($name, $settings->get($name));
            ?>
            </span>
        </label>

        <?php
        if ($option->helptext) {
        ?>
        <div class="helptext">
            <p class="description"><?php echo $option->helptext; ?></p>
        </div>
        <?php
        }
        ?>
    </div>
    <?php
    }
    ?>
    <div class="submit">
        <input type="submit" 
            name="submit" 
            id="submit" 
            class="button button-primary" 
            value="<?php _e('Save Changes', 'yatmo-text'); ?>">
    </div>

    </form>

    </div>
</div>
